package com.engine.organization.web;

import com.engine.common.util.ParamUtil;
import com.engine.common.util.ServiceUtil;
import com.engine.organization.entity.extend.param.ExtendTitleSaveParam;
import com.engine.organization.entity.fieldset.param.FieldTypeTreeParam;
import com.engine.organization.enums.ModuleTypeEnum;
import com.engine.organization.util.response.ReturnResult;
import com.engine.organization.wrapper.FieldDefinedWrapper;
import io.swagger.v3.oas.annotations.parameters.RequestBody;
import weaver.hrm.HrmUserVarify;
import weaver.hrm.User;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.ws.rs.*;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import java.util.Map;

/**
 * @Author weaver_cl
 * @description:
 * @Date 2022/6/13
 * @Version V1.0
 **/
public class FieldDefinedController {

    private FieldDefinedWrapper getFieldDefinedWrapper(User user) {
        return ServiceUtil.getService(FieldDefinedWrapper.class, user);
    }

    @GET
    @Path("/{moduleTypeEnum}/getTree")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult getTree(@Context HttpServletRequest request, @Context HttpServletResponse response,
                                @PathParam("moduleTypeEnum") ModuleTypeEnum moduleTypeEnum) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return getFieldDefinedWrapper(user).getTree(moduleTypeEnum);
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    @POST
    @Path("/{moduleTypeEnum}/saveTree")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult saveTree(@Context HttpServletRequest request, @Context HttpServletResponse response,
                                    @PathParam("moduleTypeEnum") ModuleTypeEnum moduleTypeEnum) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return getFieldDefinedWrapper(user).getTree(moduleTypeEnum);
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    @POST
    @Path("/{moduleTypeEnum}/addTree")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult addTree(@Context HttpServletRequest request, @Context HttpServletResponse response,
                                @PathParam("moduleTypeEnum") ModuleTypeEnum moduleTypeEnum, @RequestBody FieldTypeTreeParam fieldTypeTreeParam) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return getFieldDefinedWrapper(user).addTree(moduleTypeEnum, fieldTypeTreeParam);
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    @POST
    @Path("/{moduleTypeEnum}/editTree")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult editTree(@Context HttpServletRequest request, @Context HttpServletResponse response,
                                @PathParam("moduleTypeEnum") ModuleTypeEnum moduleTypeEnum,@RequestBody FieldTypeTreeParam fieldTypeTreeParam) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return getFieldDefinedWrapper(user).getTree(moduleTypeEnum);
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    @GET
    @Path("/getTabInfo")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult getTabInfo(@Context HttpServletRequest request, @Context HttpServletResponse response) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            Map<String, Object> map = ParamUtil.request2Map(request);
            String groupType = (String) map.get("groupType");
            return ReturnResult.successed(getFieldDefinedWrapper(user).getTabInfo(groupType));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    /**
     * 分组维护
     *
     * @param request
     * @param response
     * @param param
     * @return
     */
    @POST
    @Path("/saveGroup")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult saveGroup(@Context HttpServletRequest request, @Context HttpServletResponse response, @RequestBody ExtendTitleSaveParam param) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getFieldDefinedWrapper(user).saveGroup(param));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    /**
     * 新建分组
     *
     * @param request
     * @param response
     * @param param
     * @return
     */
    @POST
    @Path("/saveTitle")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult saveTitle(@Context HttpServletRequest request, @Context HttpServletResponse response, @RequestBody ExtendTitleSaveParam param) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getFieldDefinedWrapper(user).saveTitle(param));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }

    @POST
    @Path("/deleteTitle")
    @Produces(MediaType.APPLICATION_JSON)
    public ReturnResult deleteTitle(@Context HttpServletRequest request, @Context HttpServletResponse response, @RequestBody ExtendTitleSaveParam param) {
        try {
            User user = HrmUserVarify.getUser(request, response);
            return ReturnResult.successed(getFieldDefinedWrapper(user).deleteTitle(param));
        } catch (Exception e) {
            return ReturnResult.exceptionHandle(e.getMessage());
        }
    }
}
